@@ -1,27 +1,35 @@
 """Create plotly figures from pandas Dataframe."""
 
+
 import numpy as np
 import plotly.io as pio
 import plotly.graph_objects as go
-from plotly.graph_objects import Figure
-from ._to_dataframe import heatmap_dataframe
-from ._helper import discontinuous_to_continuous
 from math import ceil, floor
+from plotly.graph_objects import Figure
+from typing import Union
+
+from ._to_dataframe import heatmap_dataframe
+from ._helper import discontinuous_to_continuous, rgb_to_hex
+
 from ladybug.datacollection import HourlyContinuousCollection, \
-    HourlyDiscontinuousCollection, MonthlyCollection
+    HourlyDiscontinuousCollection
 from ladybug_pandas.series import Series
+from ladybug.color import Colorset
 
 
-def heatmap(hourly_data: HourlyContinuousCollection,
-            min_range: float = None, max_range: float = None) -> Figure:
-    """Create a plotly heatmap figure from Ladybug HourlyContinuousCollection.
+def heatmap(hourly_data: Union[HourlyContinuousCollection, HourlyDiscontinuousCollection],
+            min_range: float = None, max_range: float = None,
+            colorset: Colorset = Colorset.original()) -> Figure:
+    """Create a plotly heatmap figure from Ladybug Hourly data.
 
     Args:
-        hourly_data: A Ladybug HourlyContinuousCollection object.
+        hourly_data: A Ladybug HourlyContinuousCollection object or a Ladybug
+            HourlyDiscontinuousCollection object.
         min_range: The minimum value for the legend of the heatmap. If not set, value
             will be calculated based on data. Defaults to None.
         max_range: The maximum value for the legend of the heatmap. If not set, value
             will be calculated based on data. Defaults to None.
+        colorset: A Ladybug Colorset object. Defaults to Original Ladybug Colorset.
 
     Returns:
         A plotly figure.
@@ -57,11 +65,12 @@ def heatmap(hourly_data: HourlyContinuousCollection,
             z=df[var],
             zmin=range_z[0],
             zmax=range_z[1],
+            colorscale=rgb_to_hex(colorset),
             customdata=np.stack((df["month_names"], df["day"]), axis=-1),
             hovertemplate=(
                 "<b>"
                 + var
-                + ": %{z:.2f} "
+                + ": %{z} "
                 + var_unit
                 + "</b><br>Month: %{customdata[0]}<br>Day: %{customdata[1]}<br>Hour: %{y}:00<br>"
             ),
